@@ -3,7 +3,7 @@
 // Purpose:     Cairo render
 // Author:      Alex Thuering
 // Created:     2005/05/12
-// RCS-ID:      $Id: SVGCanvasCairo.cpp,v 1.17 2011/11/22 21:09:42 ntalex Exp $
+// RCS-ID:      $Id: SVGCanvasCairo.cpp,v 1.19 2012/01/08 02:44:12 ntalex Exp $
 // Copyright:   (c) 2005 Alex Thuering
 // Licence:     wxWindows licence
 //////////////////////////////////////////////////////////////////////////////
@@ -373,7 +373,7 @@ void wxSVGCanvasCairo::DrawCanvasPath(wxSVGCanvasPathCairo& canvasPath, wxSVGMat
 	// check Filter
 	if (style.GetFilter().GetCSSPrimitiveType() == wxCSS_URI && style.GetFilter().GetStringValue().length() > 1) {
 		wxString filterId = style.GetFilter().GetStringValue().substr(1);
-		wxSVGElement* filterElem = (wxSVGSVGElement*) svgElem.GetElementById(filterId);
+		wxSVGElement* filterElem = (wxSVGElement*) svgElem.GetElementById(filterId);
 		// feGaussianBlur
 		if (filterElem && filterElem->GetDtd() == wxSVG_FILTER_ELEMENT && filterElem->GetFirstChild() != NULL
 				&& ((wxSVGSVGElement*) filterElem->GetFirstChild())->GetDtd() == wxSVG_FEGAUSSIANBLUR_ELEMENT) {
@@ -428,6 +428,57 @@ void wxSVGCanvasCairo::DrawCanvasImage(wxSVGCanvasImage& canvasImage, cairo_patt
 	cairo_matrix_init(&mat, matrix.GetA(), matrix.GetB(), matrix.GetC(), matrix.GetD(), matrix.GetE(), matrix.GetF());
 	cairo_set_matrix(m_cr, &mat);
 	
+	// ClipPath
+	if (style.GetClipPath().GetCSSPrimitiveType() == wxCSS_URI && style.GetClipPath().GetStringValue().length() > 1) {
+		wxString clipPathId = style.GetClipPath().GetStringValue().substr(1);
+		wxSVGElement* clipPathElem = (wxSVGElement*) svgElem.GetElementById(clipPathId);
+		if (clipPathElem && clipPathElem->GetDtd() == wxSVG_CLIPPATH_ELEMENT) {
+			wxSVGElement* elem = (wxSVGElement*) clipPathElem->GetFirstChild();
+			while (elem != NULL) {
+				if (elem->GetOwnerSVGElement() == NULL)
+					elem->SetOwnerSVGElement(&svgElem);
+				if (elem->GetViewportElement() == NULL)
+					elem->SetViewportElement(&svgElem);
+				wxSVGDocument* doc = (wxSVGDocument*) elem->GetOwnerDocument();
+				wxSVGCanvasItem* canvasItem = NULL;
+				switch (elem->GetDtd()) {
+				case wxSVG_LINE_ELEMENT:
+					canvasItem = doc->GetCanvas()->CreateItem((wxSVGLineElement*) elem);
+					break;
+				case wxSVG_POLYLINE_ELEMENT:
+					canvasItem = doc->GetCanvas()->CreateItem((wxSVGPolylineElement*) elem);
+					break;
+				case wxSVG_POLYGON_ELEMENT:
+					canvasItem = doc->GetCanvas()->CreateItem((wxSVGPolygonElement*) elem);
+					break;
+				case wxSVG_RECT_ELEMENT:
+					canvasItem = doc->GetCanvas()->CreateItem((wxSVGRectElement*) elem);
+					break;
+				case wxSVG_CIRCLE_ELEMENT:
+					canvasItem = doc->GetCanvas()->CreateItem((wxSVGCircleElement*) elem);
+					break;
+				case wxSVG_ELLIPSE_ELEMENT: {
+					canvasItem = doc->GetCanvas()->CreateItem((wxSVGEllipseElement*) elem);
+					break;
+				}
+				case wxSVG_PATH_ELEMENT:
+					canvasItem = doc->GetCanvas()->CreateItem((wxSVGPathElement*) elem);
+					break;
+				default:
+					break;
+				}
+				if (canvasItem != NULL) {
+					cairo_path_t* path = ((wxSVGCanvasPathCairo*) canvasItem)->GetPath();
+					cairo_append_path(m_cr, path);
+					cairo_clip(m_cr);
+					//cairo_path_destroy(path);
+					delete canvasItem;
+				}
+				elem = (wxSVGElement*) elem->GetNextSibling();
+			}
+		}
+	}
+	
 	// scale context
 	double x = canvasImage.m_x;
 	double y = canvasImage.m_y;
@@ -436,6 +487,7 @@ void wxSVGCanvasCairo::DrawCanvasImage(wxSVGCanvasImage& canvasImage, cairo_patt
 	wxSVG_PRESERVEASPECTRATIO align = canvasImage.GetPreserveAspectRatio().GetAlign();
 	bool alignX = false;
 	if (align > wxSVG_PRESERVEASPECTRATIO_NONE) {
+		scaleY = canvasImage.m_height / canvasImage.GetDefaultHeight();
 		if (canvasImage.GetPreserveAspectRatio().GetMeetOrSlice() != wxSVG_MEETORSLICE_SLICE) {
 			alignX = scaleX > scaleY;
 		} else {
@@ -448,22 +500,23 @@ void wxSVGCanvasCairo::DrawCanvasImage(wxSVGCanvasImage& canvasImage, cairo_patt
 			if (align == wxSVG_PRESERVEASPECTRATIO_XMIDYMIN
 					|| align == wxSVG_PRESERVEASPECTRATIO_XMIDYMID
 					|| align == wxSVG_PRESERVEASPECTRATIO_XMIDYMAX)
-				x += (canvasImage.m_width - canvasImage.m_image.GetWidth() * scaleX) / 2;
+				x += (canvasImage.m_width - canvasImage.GetDefaultWidth() * scaleX) / 2;
 			else if (align == wxSVG_PRESERVEASPECTRATIO_XMAXYMIN
 					|| align == wxSVG_PRESERVEASPECTRATIO_XMAXYMID
 					|| align == wxSVG_PRESERVEASPECTRATIO_XMAXYMAX)
-				x += canvasImage.m_width - canvasImage.m_image.GetWidth() * scaleX;
+				x += canvasImage.m_width - canvasImage.GetDefaultWidth() * scaleX;
 		} else {
 			scaleY = scaleX;
 			if (align == wxSVG_PRESERVEASPECTRATIO_XMINYMID
 					|| align == wxSVG_PRESERVEASPECTRATIO_XMIDYMID
 					|| align == wxSVG_PRESERVEASPECTRATIO_XMAXYMID)
-				y += (canvasImage.m_height - canvasImage.m_image.GetHeight() * scaleY) / 2;
+				y += (canvasImage.m_height - canvasImage.GetDefaultHeight() * scaleY) / 2;
 			else if (align == wxSVG_PRESERVEASPECTRATIO_XMINYMAX
 					|| align == wxSVG_PRESERVEASPECTRATIO_XMIDYMAX
 					|| align == wxSVG_PRESERVEASPECTRATIO_XMAXYMAX)
-				y += canvasImage.m_height - canvasImage.m_image.GetHeight() * scaleY;
+				y += canvasImage.m_height - canvasImage.GetDefaultHeight() * scaleY;
 		}
+		scaleY = scaleY * canvasImage.GetDefaultHeight() / canvasImage.m_image.GetHeight();
 	}
 	cairo_translate(m_cr, x, y);
 	cairo_scale(m_cr, scaleX, scaleY);
