@@ -3,7 +3,7 @@
 // Purpose:     Cairo canvas path
 // Author:      Alex Thuering
 // Created:     2005/05/12
-// RCS-ID:      $Id: SVGCanvasPathCairo.cpp,v 1.6 2011/10/31 07:53:01 ntalex Exp $
+// RCS-ID:      $Id: SVGCanvasPathCairo.cpp,v 1.7 2012/01/08 02:43:09 ntalex Exp $
 // Copyright:   (c) 2005 Alex Thuering
 // Licence:     wxWindows licence
 //////////////////////////////////////////////////////////////////////////////
@@ -53,7 +53,10 @@ wxSVGRect wxSVGCanvasPathCairo::GetResultBBox(const wxCSSStyleDeclaration& style
 	}
 	ApplyStrokeStyle(m_cr, style);
 	double x1, y1, x2, y2;
-	cairo_stroke_extents(m_cr, &x1, &y1, &x2, &y2);
+	if (style.GetStrokeWidth() > 0)
+		cairo_stroke_extents(m_cr, &x1, &y1, &x2, &y2);
+	else
+		cairo_fill_extents(m_cr, &x1, &y1, &x2, &y2);
 	if (&matrix) {
 		cairo_matrix_t mat;
 		cairo_matrix_init(&mat, 1, 0, 0, 1, 0, 0);
