@@ -3,7 +3,7 @@
 // Purpose:     Libart render
 // Author:      Alex Thuering
 // Created:     2005/05/06
-// RCS-ID:      $Id: SVGCanvasLibart.cpp,v 1.21 2010/08/29 17:57:52 ntalex Exp $
+// RCS-ID:      $Id: SVGCanvasLibart.cpp,v 1.22 2011/06/27 21:14:14 ntalex Exp $
 // Copyright:   (c) 2005 Alex Thuering
 // Licence:     wxWindows licence
 //////////////////////////////////////////////////////////////////////////////
@@ -21,32 +21,26 @@
 #include "../freetype/SVGCanvasTextFreetype.h"
 #include <wx/log.h>
 
-void wxSVGCanvasLibart::Init(int width, int height)
-{
+void wxSVGCanvasLibart::Init(int width, int height, bool alpha) {
   m_image.Create(width, height);
 }
 
-wxImage wxSVGCanvasLibart::GetImage()
-{
+wxImage wxSVGCanvasLibart::GetImage() {
   return m_image;
 }
 
-void wxSVGCanvasLibart::Clear(wxRGBColor color)
-{
+void wxSVGCanvasLibart::Clear(wxRGBColor color) {
   if (!m_image.Ok())
     return;
   art_rgb_fill_run(m_image.GetData(), color.Red(), color.Green(), color.Blue(),
     m_image.GetWidth()*m_image.GetHeight());
 }
 
-wxSVGCanvasPath* wxSVGCanvasLibart::CreateCanvasPath()
-{
+wxSVGCanvasPath* wxSVGCanvasLibart::CreateCanvasPath() {
   return new wxSVGCanvasPathLibart();
 }
 
-wxSVGCanvasItem* wxSVGCanvasLibart::CreateItem(wxSVGTextElement* element,
-  const wxCSSStyleDeclaration* style)
-{
+wxSVGCanvasItem* wxSVGCanvasLibart::CreateItem(wxSVGTextElement* element, const wxCSSStyleDeclaration* style) {
   wxSVGCanvasText* canvasText = new wxSVGCanvasTextFreetype(this);
   if (style == NULL)
 	style = &element->GetStyle();
@@ -150,11 +144,11 @@ void wxSVGCanvasLibart::PaintSVP(ArtSVP* fillSVP, const wxSVGPaint& paint,
     if (paint.GetPaintType() >= wxSVG_PAINTTYPE_URI_NONE &&
         paint.GetPaintType() <= wxSVG_PAINTTYPE_URI)
     {
-        const wxSVGElement* refElem;
-        m_nstops = GetGradientStops(svgElem, paint.GetUri(), opacity, refElem);
+    	wxSVGGradientElement* gradElem = GetGradientElement(svgElem, paint.GetUri());
+        m_nstops = GetGradientStops(svgElem, gradElem, opacity);
         if (m_nstops)
         {
-            switch (refElem->GetDtd())
+            switch (gradElem->GetDtd())
             {
                 case wxSVG_LINEARGRADIENT_ELEMENT:
                 {
@@ -163,8 +157,7 @@ void wxSVGCanvasLibart::PaintSVP(ArtSVP* fillSVP, const wxSVGPaint& paint,
                     gradient.stops = m_stops;
                     double dx, dy;
                     wxSVGPoint p1,p2;
-                    wxSVGLinearGradientElement* gradElem = (wxSVGLinearGradientElement*)refElem;
-                    GetLinearGradientVector(p1, p2, *gradElem, path);
+                    GetLinearGradientVector(p1, p2, (wxSVGLinearGradientElement&) *gradElem, path);
                     p1 = p1.MatrixTransform(matrix);
                     p2 = p2.MatrixTransform(matrix);
                     /* solve a, b, c so ax1 + by1 + c = 0 and ax2 + by2 + c = 1, maximum
@@ -193,10 +186,9 @@ void wxSVGCanvasLibart::PaintSVP(ArtSVP* fillSVP, const wxSVGPaint& paint,
                     gradient.stops = m_stops;
                     
                     // Get Gradient transformation
-                    wxSVGRadialGradientElement* gradElem = (wxSVGRadialGradientElement*)refElem;
                     wxSVGPoint focus;
                     wxSVGMatrix rgMatrix = matrix;
-                    GetRadialGradientTransform(focus, rgMatrix, *gradElem, path, true);
+                    GetRadialGradientTransform(focus, rgMatrix, (wxSVGRadialGradientElement&) *gradElem, path, true);
                     rgMatrix = rgMatrix.Inverse();
                     
                     gradient.affine[0] = rgMatrix.GetA();
